@@ -154,6 +154,14 @@ class imagebuilderClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client/#cancel_image_creation)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/imagebuilder.html#imagebuilder.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client/#close)
+        """
+
     def create_component(
         self,
         *,
@@ -183,12 +191,12 @@ class imagebuilderClient(BaseClient):
         containerType: Literal["DOCKER"],
         name: str,
         semanticVersion: str,
-        components: Sequence["ComponentConfigurationTypeDef"],
+        components: Sequence[ComponentConfigurationTypeDef],
         parentImage: str,
-        targetRepository: "TargetContainerRepositoryTypeDef",
+        targetRepository: TargetContainerRepositoryTypeDef,
         clientToken: str,
         description: str = ...,
-        instanceConfiguration: "InstanceConfigurationTypeDef" = ...,
+        instanceConfiguration: InstanceConfigurationTypeDef = ...,
         dockerfileTemplateData: str = ...,
         dockerfileTemplateUri: str = ...,
         platformOverride: PlatformType = ...,
@@ -208,7 +216,7 @@ class imagebuilderClient(BaseClient):
         self,
         *,
         name: str,
-        distributions: Sequence["DistributionTypeDef"],
+        distributions: Sequence[DistributionTypeDef],
         clientToken: str,
         description: str = ...,
         tags: Mapping[str, str] = ...
@@ -228,7 +236,7 @@ class imagebuilderClient(BaseClient):
         imageRecipeArn: str = ...,
         containerRecipeArn: str = ...,
         distributionConfigurationArn: str = ...,
-        imageTestsConfiguration: "ImageTestsConfigurationTypeDef" = ...,
+        imageTestsConfiguration: ImageTestsConfigurationTypeDef = ...,
         enhancedImageMetadataEnabled: bool = ...,
         tags: Mapping[str, str] = ...
     ) -> CreateImageResponseTypeDef:
@@ -249,9 +257,9 @@ class imagebuilderClient(BaseClient):
         imageRecipeArn: str = ...,
         containerRecipeArn: str = ...,
         distributionConfigurationArn: str = ...,
-        imageTestsConfiguration: "ImageTestsConfigurationTypeDef" = ...,
+        imageTestsConfiguration: ImageTestsConfigurationTypeDef = ...,
         enhancedImageMetadataEnabled: bool = ...,
-        schedule: "ScheduleTypeDef" = ...,
+        schedule: ScheduleTypeDef = ...,
         status: PipelineStatusType = ...,
         tags: Mapping[str, str] = ...
     ) -> CreateImagePipelineResponseTypeDef:
@@ -267,14 +275,14 @@ class imagebuilderClient(BaseClient):
         *,
         name: str,
         semanticVersion: str,
-        components: Sequence["ComponentConfigurationTypeDef"],
+        components: Sequence[ComponentConfigurationTypeDef],
         parentImage: str,
         clientToken: str,
         description: str = ...,
-        blockDeviceMappings: Sequence["InstanceBlockDeviceMappingTypeDef"] = ...,
+        blockDeviceMappings: Sequence[InstanceBlockDeviceMappingTypeDef] = ...,
         tags: Mapping[str, str] = ...,
         workingDirectory: str = ...,
-        additionalInstanceConfiguration: "AdditionalInstanceConfigurationTypeDef" = ...
+        additionalInstanceConfiguration: AdditionalInstanceConfigurationTypeDef = ...
     ) -> CreateImageRecipeResponseTypeDef:
         """
         Creates a new image recipe.
@@ -293,12 +301,12 @@ class imagebuilderClient(BaseClient):
         instanceTypes: Sequence[str] = ...,
         securityGroupIds: Sequence[str] = ...,
         subnetId: str = ...,
-        logging: "LoggingTypeDef" = ...,
+        logging: LoggingTypeDef = ...,
         keyPair: str = ...,
         terminateInstanceOnFailure: bool = ...,
         snsTopicArn: str = ...,
         resourceTags: Mapping[str, str] = ...,
-        instanceMetadataOptions: "InstanceMetadataOptionsTypeDef" = ...,
+        instanceMetadataOptions: InstanceMetadataOptionsTypeDef = ...,
         tags: Mapping[str, str] = ...
     ) -> CreateInfrastructureConfigurationResponseTypeDef:
         """
@@ -538,7 +546,7 @@ class imagebuilderClient(BaseClient):
         self,
         *,
         owner: OwnershipType = ...,
-        filters: Sequence["FilterTypeDef"] = ...,
+        filters: Sequence[FilterTypeDef] = ...,
         byName: bool = ...,
         maxResults: int = ...,
         nextToken: str = ...
@@ -554,7 +562,7 @@ class imagebuilderClient(BaseClient):
         self,
         *,
         owner: OwnershipType = ...,
-        filters: Sequence["FilterTypeDef"] = ...,
+        filters: Sequence[FilterTypeDef] = ...,
         maxResults: int = ...,
         nextToken: str = ...
     ) -> ListContainerRecipesResponseTypeDef:
@@ -566,11 +574,7 @@ class imagebuilderClient(BaseClient):
         """
 
     def list_distribution_configurations(
-        self,
-        *,
-        filters: Sequence["FilterTypeDef"] = ...,
-        maxResults: int = ...,
-        nextToken: str = ...
+        self, *, filters: Sequence[FilterTypeDef] = ..., maxResults: int = ..., nextToken: str = ...
     ) -> ListDistributionConfigurationsResponseTypeDef:
         """
         Returns a list of distribution configurations.
@@ -583,7 +587,7 @@ class imagebuilderClient(BaseClient):
         self,
         *,
         imageVersionArn: str,
-        filters: Sequence["FilterTypeDef"] = ...,
+        filters: Sequence[FilterTypeDef] = ...,
         maxResults: int = ...,
         nextToken: str = ...
     ) -> ListImageBuildVersionsResponseTypeDef:
@@ -609,7 +613,7 @@ class imagebuilderClient(BaseClient):
         self,
         *,
         imagePipelineArn: str,
-        filters: Sequence["FilterTypeDef"] = ...,
+        filters: Sequence[FilterTypeDef] = ...,
         maxResults: int = ...,
         nextToken: str = ...
     ) -> ListImagePipelineImagesResponseTypeDef:
@@ -621,11 +625,7 @@ class imagebuilderClient(BaseClient):
         """
 
     def list_image_pipelines(
-        self,
-        *,
-        filters: Sequence["FilterTypeDef"] = ...,
-        maxResults: int = ...,
-        nextToken: str = ...
+        self, *, filters: Sequence[FilterTypeDef] = ..., maxResults: int = ..., nextToken: str = ...
     ) -> ListImagePipelinesResponseTypeDef:
         """
         Returns a list of image pipelines.
@@ -638,7 +638,7 @@ class imagebuilderClient(BaseClient):
         self,
         *,
         owner: OwnershipType = ...,
-        filters: Sequence["FilterTypeDef"] = ...,
+        filters: Sequence[FilterTypeDef] = ...,
         maxResults: int = ...,
         nextToken: str = ...
     ) -> ListImageRecipesResponseTypeDef:
@@ -653,7 +653,7 @@ class imagebuilderClient(BaseClient):
         self,
         *,
         owner: OwnershipType = ...,
-        filters: Sequence["FilterTypeDef"] = ...,
+        filters: Sequence[FilterTypeDef] = ...,
         byName: bool = ...,
         maxResults: int = ...,
         nextToken: str = ...,
@@ -667,11 +667,7 @@ class imagebuilderClient(BaseClient):
         """
 
     def list_infrastructure_configurations(
-        self,
-        *,
-        filters: Sequence["FilterTypeDef"] = ...,
-        maxResults: int = ...,
-        nextToken: str = ...
+        self, *, filters: Sequence[FilterTypeDef] = ..., maxResults: int = ..., nextToken: str = ...
     ) -> ListInfrastructureConfigurationsResponseTypeDef:
         """
         Returns a list of infrastructure configurations.
@@ -756,7 +752,7 @@ class imagebuilderClient(BaseClient):
         self,
         *,
         distributionConfigurationArn: str,
-        distributions: Sequence["DistributionTypeDef"],
+        distributions: Sequence[DistributionTypeDef],
         clientToken: str,
         description: str = ...
     ) -> UpdateDistributionConfigurationResponseTypeDef:
@@ -777,9 +773,9 @@ class imagebuilderClient(BaseClient):
         imageRecipeArn: str = ...,
         containerRecipeArn: str = ...,
         distributionConfigurationArn: str = ...,
-        imageTestsConfiguration: "ImageTestsConfigurationTypeDef" = ...,
+        imageTestsConfiguration: ImageTestsConfigurationTypeDef = ...,
         enhancedImageMetadataEnabled: bool = ...,
-        schedule: "ScheduleTypeDef" = ...,
+        schedule: ScheduleTypeDef = ...,
         status: PipelineStatusType = ...
     ) -> UpdateImagePipelineResponseTypeDef:
         """
@@ -799,12 +795,12 @@ class imagebuilderClient(BaseClient):
         instanceTypes: Sequence[str] = ...,
         securityGroupIds: Sequence[str] = ...,
         subnetId: str = ...,
-        logging: "LoggingTypeDef" = ...,
+        logging: LoggingTypeDef = ...,
         keyPair: str = ...,
         terminateInstanceOnFailure: bool = ...,
         snsTopicArn: str = ...,
         resourceTags: Mapping[str, str] = ...,
-        instanceMetadataOptions: "InstanceMetadataOptionsTypeDef" = ...
+        instanceMetadataOptions: InstanceMetadataOptionsTypeDef = ...
     ) -> UpdateInfrastructureConfigurationResponseTypeDef:
         """
         Updates a new infrastructure configuration.
